package CommentCustomField::CMS;

use strict;
use warnings;

use CGI;
use File::Basename;
use MT::Util qw( dirify );

sub save_comment_customfield {
    my ($eh, $comment) = @_;

    my $app = MT->instance;
    return if (!$app->can('param')); 

    my $plugin = MT->component("CommentCustomField");

    if ($app->{query}->param('comment-custom-text')) {
        $comment->custom_text($app->{query}->param('comment-custom-text'));
    }

    if ($app->{query}->param('comment-custom-textarea')) {
        $comment->custom_textarea($app->{query}->param('comment-custom-textarea'));
    }

    if ($app->{query}->param('comment-custom-checkbox')) {
        my @checkbox_list = $app->{query}->param('comment-custom-checkbox');
        my $checkbox_sep = $plugin->get_config_value('comment_checkbox_separator', 'blog:' . $app->blog->id) || ',';
        $comment->custom_checkbox(join($checkbox_sep, @checkbox_list));
    }

    if ($app->{query}->param('comment-custom-radio')) {
        $comment->custom_radio($app->{query}->param('comment-custom-radio'));
    }

    if ($app->{query}->param('comment-custom-select')) {
        my @select_list = $app->{query}->param('comment-custom-select');
        my $select_sep = $plugin->get_config_value('comment_select_separator', 'blog:' . $app->blog->id) || ',';
        $comment->custom_select(join($select_sep, @select_list));
    }

    if ($app->{query}->param("comment-custom-image")) {
        my $asset = _handle_upload('comment-custom-image', require_type => 'image');
        return 1 if !$asset;
        $comment->custom_image($asset->id);
    }

    1;
}

sub edit_comment_customfield {
    my ($eh, $app, $param, $tmpl) = @_;
    my ($node, $host_node, $innerHTML);

    my $plugin = MT->component("CommentCustomField");

    my $use_textarea = $plugin->get_config_value('use_comment_customfield_textarea', 'blog:' . $app->blog->id);
    if ($use_textarea) {
      $node = $tmpl->createElement('app:setting');
      $node->setAttribute('id', 'comment_custom_textarea');
      $node->setAttribute('label', $plugin->translate('Comment CustomField Textarea'));
      my $comment_custom_textarea = $param->{custom_textarea};
      $innerHTML = <<HERE;
        <textarea name="comment-custom-textarea" id="comment-custom-textarea" style="width:90%">$comment_custom_textarea</textarea>
HERE
      $node->innerHTML($innerHTML);
      $host_node = $tmpl->getElementById('text');
      $tmpl->insertAfter($node, $host_node);
    }

    my $use_text = $plugin->get_config_value('use_comment_customfield_text', 'blog:' . $app->blog->id);
    if ($use_text) {
      $node = $tmpl->createElement('app:setting');
      $node->setAttribute('id', 'comment_custom_text');
      $node->setAttribute('label', $plugin->translate('Comment CustomField Textfield'));
      my $comment_custom_text = $param->{custom_text};
      $innerHTML = <<HERE;
        <input name="comment-custom-text" id="comment-custom-text" value="${comment_custom_text}" style="width:90%" />
HERE
      $node->innerHTML($innerHTML);
      $host_node = $tmpl->getElementById('text');
      $tmpl->insertAfter($node, $host_node);
    }

    my $use_radio = $plugin->get_config_value('use_comment_customfield_radio', 'blog:' . $app->blog->id);
    if ($use_radio) {
      $node = $tmpl->createElement('app:setting');
      $node->setAttribute('id', 'comment_custom_radio');
      $node->setAttribute('label', $plugin->translate('Comment CustomField Radio'));
      my $comment_custom_radio = $param->{custom_radio};
      $innerHTML = <<HERE;
        <input name="comment-custom-radio" id="comment-custom-radio" value="${comment_custom_radio}" style="width:90%" />
HERE
      $node->innerHTML($innerHTML);
      $host_node = $tmpl->getElementById('text');
      $tmpl->insertAfter($node, $host_node);
    }

    my $use_checkbox = $plugin->get_config_value('use_comment_customfield_checkbox', 'blog:' . $app->blog->id);
    if ($use_checkbox) {
      $node = $tmpl->createElement('app:setting');
      $node->setAttribute('id', 'comment_custom_checkbox');
      $node->setAttribute('label', $plugin->translate('Comment CustomField Checkbox'));
      my $comment_custom_checkbox = $param->{custom_checkbox};
      $innerHTML = <<HERE;
        <input name="comment-custom-checkbox" id="comment-custom-checkbox" value="${comment_custom_checkbox}" style="width:90%" />
HERE
      $node->innerHTML($innerHTML);
      $host_node = $tmpl->getElementById('text');
      $tmpl->insertAfter($node, $host_node);
    }

    my $use_select = $plugin->get_config_value('use_comment_customfield_select', 'blog:' . $app->blog->id);
    if ($use_select) {
      $node = $tmpl->createElement('app:setting');
      $node->setAttribute('id', 'comment_custom_select');
      $node->setAttribute('label', $plugin->translate('Comment CustomField Select'));
      my $comment_custom_select = $param->{custom_select};
      $innerHTML = <<HERE;
        <input name="comment-custom-select" id="comment-custom-select" value="${comment_custom_select}" style="width:90%" />
HERE
      $node->innerHTML($innerHTML);
      $host_node = $tmpl->getElementById('text');
      $tmpl->insertAfter($node, $host_node);
    }
}

# Thanks Community.pm _handle_upload
sub _handle_upload {
    my ($param, %options) = @_;
    my $app = MT->instance;

    my $plugin = MT->component("CommentCustomField");

    my ($fh, $no_upload);
    my $q = CGI->new();
    eval { $fh = $q->upload($param) };
    if ( $@ && $@ =~ /^Undefined subroutine/ ) {
        $fh = $q->param($param);
    }
    $no_upload = !$fh;
    return 0 if $no_upload;

    my $info = $q->uploadInfo($fh);
    my $mimetype;
    if ($info) {
        $mimetype = $info->{'Content-Type'};
    }

    # TCY
    my $maxsize = $plugin->get_config_value('comment_image_max_size', 'blog:' . $app->blog->id) || 300;
    my $size = (stat($fh))[7];
    return 0 if ($size > $maxsize * 1024);

    my $basename = basename($fh);

    $basename =~ s!\\!/!g;    ## Change backslashes to forward slashes
    $basename =~ s!^.*/!!;    ## Get rid of full directory paths
    if ( $basename =~ m!\.\.|\0|\|! ) {
        return $app->errtrans( "Invalid filename '[_1]'", $basename );
    }
    my ($base, $uploaded_path, $ext) = File::Basename::fileparse($basename, '\.[^\.]*');
    # dirify $base
    $base = dirify( $base );

    if ($plugin->get_config_value('comment_image_add_timestamp', 'blog:' . $app->blog->id)) {
        my ($sec, $min, $hour, $mday, $mon, $year, $wday, $yday, $isdst) = gmtime(time);
        my $timestamp = sprintf("%04d%02d%02d%02d%02d%02d", $year + 1900, $mon +1, $mday, $hour, $min, $sec);
        $base .= '_comment' . $timestamp;
    }

    if (my $asset_type = $options{require_type}) {
        require MT::Asset;
        my $asset_pkg = MT::Asset->handler_for_file($basename);
        if ($asset_type eq 'image') {
            return $app->errtrans( "Please select an image to upload." )
              if !$asset_pkg->isa('MT::Asset::Image');
        }
    }

    my ($blog_id, $blog, $save_path, $local_path, $fmgr, %complements);

    $blog_id    = $app->blog->id;
    $save_path  = '%r'. '/' . $plugin->get_config_value('comment_image_upload_path', 'blog:' . $app->blog->id);
    $save_path .= '/' unless $save_path =~ m|/$|;
    if ($plugin->get_config_value('comment_image_upload_path', 'blog:' . $app->blog->id)) {
        $local_path = File::Spec->catdir(
                 $app->blog->site_path . '/' . $plugin->get_config_value('comment_image_upload_path', 'blog:' . $app->blog->id));
        require MT::FileMgr;
        my $fmgr = MT::FileMgr->new('Local');
        $fmgr->mkpath($local_path);
    } else {
        $local_path = File::Spec->catdir($app->blog->site_path);
    }

    require MT::FileMgr;
    $fmgr = MT::FileMgr->new('Local');
    %complements = (
        Max => ($app->config('UserpicMaxUpload') || 0),
        Square => ($options{square} || 0),
    );

    # Find unique name for the file.
    my $i = 1;
    my $base_copy = $base;
    while ($fmgr->exists(File::Spec->catfile($local_path, $base . $ext))) {
        $base = $base_copy . '_' . $i++;
    }

    my $local_relative = File::Spec->catfile($save_path, $base . $ext);
    my $local = File::Spec->catfile($local_path, $base . $ext);

    require MT::Image;
    require Carp;
    my ($w, $h, $id, $write_file) = MT::Image->check_upload(
        Fh => $fh, Fmgr => $fmgr, Local => $local,
        %complements
    );

    return $app->error(MT::Image->errstr)
        unless $write_file;
    my $umask = oct $app->config('UploadUmask');
    my $old   = umask($umask);
    defined( my $bytes = $write_file->() )
      or return $app->error(
        $app->translate(
            "Error writing upload to '[_1]': [_2]", $local,
            $fmgr->errstr
        )
      );
    umask($old);

    ## Close up the filehandle.
    close $fh;

    require MT::Asset;
    my $asset_pkg = MT::Asset->handler_for_file($local);
    my $is_image  = defined($w)
      && defined($h)
      && $asset_pkg->isa('MT::Asset::Image');
    my $asset;
    $asset = $asset_pkg->new();
    $asset->file_path($local_relative);
    $asset->file_name($base.$ext);
    my $ext_copy = $ext;
    $ext_copy =~ s/\.//;
    $asset->file_ext($ext_copy);
    $asset->blog_id($blog_id);

    my $original = $asset->clone;
    my $url = $local_relative;
    $url  =~ s!\\!/!g;
    $asset->url($url);
    if ($is_image) {
        $asset->image_width($w);
        $asset->image_height($h);
    }
    $asset->mime_type($mimetype);

    $asset->save
        or return $app->error($asset->errstr);
    $asset;
}

1;
