package CommentCustomField::Tags;

use strict;
use warnings;

sub comment_customfield_asset {
    my ($ctx, $args, $cond) = @_;

    my $tokens = $ctx->stash('tokens');
    my $builder = $ctx->stash('builder');

    require MT::Asset;

    my $comment = $ctx->stash('comment');
    my $id = $comment->custom_image;
    return '' unless $id;

    my $asset = MT::Asset->load($id);
    return '' unless $asset;

    my $blog = $ctx->stash('blog');
    return '' if $asset->blog_id != $blog->id;

    local $ctx->{__stash}{asset} = $asset;
    defined(my $out = $builder->build($ctx, $tokens))
        or return $ctx->error($builder->errstr);
    $out;
}

sub comment_customfield_text {
    my ($ctx, $args) = @_;
    my $comment = $ctx->stash('comment');
    if ($comment && $comment->id) {
        return $comment->custom_text;
    }
    else {
        return '';
    }
}

sub comment_customfield_textarea {
    my ($ctx, $args) = @_;
    my $comment = $ctx->stash('comment');
    if ($comment && $comment->id) {
        return $comment->custom_textarea;
    }
    else {
        return '';
    }
}

sub comment_customfield_radio_input_value {
    my ($ctx, $args) = @_;
    my $plugin = MT->component("CommentCustomField");
    my $comment = $ctx->stash('comment');
    my $app = MT->instance;
    my $radio_input_value = $plugin->get_config_value('comment_radio_initial_data', 'blog:' . $app->blog->id) || ',';
    if ($radio_input_value) {
        my @radio_list = split(/,/, $radio_input_value);
        my $radio_data;
        for (@radio_list) {
            my $checked = '';
            if (/\*$/) {
                chop;
                $checked = 'checked="checked" ';
            }
            $radio_data .= "<label class=\"input_radio_label\"><input type=\"radio\" class=\"input_radio\" name=\"comment-custom-radio\" value=\"$_\" ${checked}/><span class=\"input_radio_value\">$_</span></label> " ;
        }
        return $radio_data;
    }
    else {
        return '';
    }
}

sub comment_customfield_radio {
    my ($ctx, $args) = @_;
    my $comment = $ctx->stash('comment');
    if ($comment && $comment->id) {
        return $comment->custom_radio;
    }
    else {
        return '';
    }
}

sub comment_customfield_checkbox_input_value {
    my ($ctx, $args) = @_;
    my $comment = $ctx->stash('comment');
    my $app = MT->instance;
    my $plugin = MT->component("CommentCustomField");
    my $checkbox_input_value = $plugin->get_config_value('comment_checkbox_initial_data', 'blog:' . $app->blog->id) || ',';
    if ($checkbox_input_value) {
        my @checkbox_list = split(/,/, $checkbox_input_value);
        my $checkbox_data;
        for (@checkbox_list) {
            my $checked = '';
            if (/\*$/) {
                chop;
                $checked = 'checked="checked" ';
            }
            $checkbox_data .= "<label class=\"input_checkbox_label\"><input type=\"checkbox\" class=\"input_checkbox\" name=\"comment-custom-checkbox\" value=\"$_\" ${checked}/><span class=\"input_checkbox_value\">$_</span></label> " ;
        }
        return $checkbox_data;
    }
    else {
        return '';
    }
}

sub comment_customfield_checkbox {
    my ($ctx, $args) = @_;
    my $comment = $ctx->stash('comment');
    if ($comment && $comment->id) {
        return $comment->custom_checkbox;
    }
    else {
        return '';
    }
}

sub comment_customfield_select_input_value {
    my ($ctx, $args) = @_;
    my $comment = $ctx->stash('comment');
    my $app = MT->instance;
    my $plugin = MT->component("CommentCustomField");
    my $select_input_value = $plugin->get_config_value('comment_select_initial_data', 'blog:' . $app->blog->id) || ',';
    if ($select_input_value) {
        my @select_list = split(/,/, $select_input_value);
        my $select_data = "<select class=\"input_select\" name=\"comment-custom-select\">";
        for (@select_list) {
            my $selected = '';
            if (/\*$/) {
                chop;
                $selected = ' selected="selected"';
            }
            $select_data .= "<option value=\"$_\"${selected}>$_</option>";
        }
        $select_data .= "</select>";
        return $select_data;
    }
    else {
        return '';
    }
}

sub comment_customfield_select {
    my ($ctx, $args) = @_;
    my $comment = $ctx->stash('comment');
    if ($comment && $comment->id) {
        return $comment->custom_select;
    }
    else {
        return '';
    }
}

sub comment_customfield_image_url {
    my ($ctx, $args) = @_;
    my $comment = $ctx->stash('comment');
    if ($comment && $comment->id) {
        return $comment->custom_image_url;
    }
    else {
        return '';
    }
}

sub preview_comment_customfield_text {
    my ($ctx, $args) = @_;
    my $app = MT->instance;
    return $app->param('comment-custom-text');
}

sub preview_comment_customfield_textarea {
    my ($ctx, $args) = @_;
    my $app = MT->instance;
    return $app->param('comment-custom-textarea');
}

sub preview_comment_customfield_radio_input_value {
    my ($ctx, $args) = @_;
    my $comment = $ctx->stash('comment');
    my $app = MT->instance;
    my $plugin = MT->component("CommentCustomField");
    my $radio_input_value = $plugin->get_config_value('comment_radio_initial_data', 'blog:' . $app->blog->id) || ',';
    if ($radio_input_value) {
        my @radio_list = split(/,/, $radio_input_value);
        my $radio_data;
        my $input_data = $app->param('comment-custom-radio');
        for (@radio_list) {
            chop if /\*$/;
            my $checked = '';
            if($_ eq $input_data) {
                $checked = 'checked="checked" ';
            }
            $radio_data .= "<label class=\"input_radio_label\"><input type=\"radio\" class=\"input_radio\" name=\"comment-custom-radio\" value=\"$_\" ${checked}/><span class=\"input_radio_value\">$_</span></label> " ;
        }
        return $radio_data;
    }
    else {
        return '';
    }
}

sub preview_comment_customfield_checkbox_input_value {
    my ($ctx, $args) = @_;
    my $comment = $ctx->stash('comment');
    my $app = MT->instance;
    my $plugin = MT->component("CommentCustomField");
    my $checkbox_input_value = $plugin->get_config_value('comment_checkbox_initial_data', 'blog:' . $app->blog->id) || ',';
    if ($checkbox_input_value) {
        my @checkbox_list = split(/,/, $checkbox_input_value);
        my $checkbox_data;
        my @input_data = $app->param('comment-custom-checkbox');
        for (@checkbox_list) {
            chop if /\*$/;
            my $checked = '';
            for my $cb (@input_data) {
                if($_ eq $cb) {
                    $checked = 'checked="checked" ';
                }
            }
            $checkbox_data .= "<label class=\"input_checkbox_label\"><input type=\"checkbox\" class=\"input_checkbox\" name=\"comment-custom-checkbox\" value=\"$_\" ${checked}/><span class=\"input_checkbox_value\">$_</span></label> " ;
        }
        return $checkbox_data;
    }
    else {
        return '';
    }
}

sub preview_comment_customfield_select_input_value {
    my ($ctx, $args) = @_;
    my $comment = $ctx->stash('comment');
    my $app = MT->instance;
    my $plugin = MT->component("CommentCustomField");
    my $select_input_value = $plugin->get_config_value('comment_select_initial_data', 'blog:' . $app->blog->id) || ',';
    if ($select_input_value) {
        my @select_list = split(/,/, $select_input_value);
        my $select_data = "<select class=\"input_select\" name=\"comment-custom-select\">";
        my @input_data = $app->param('comment-custom-select');
        for (@select_list) {
            chop if /\*$/;
            my $selected = '';
            for my $sl (@input_data) {
                if($_ eq $sl) {
                    $selected = ' selected="selected"';
                }
            }
            $select_data .= "<option value=\"$_\"${selected}>$_</option>";
        }
        $select_data .= "</select>";
        return $select_data;
    }
    else {
        return '';
    }
}

sub preview_comment_customfield_select {
    my ($ctx, $args) = @_;
    my $app = MT->instance;
    return $app->param('comment-custom-select');
}

1;
